@@ -1,7 +1,7 @@
 context("test-estimate_profiles.R")
 
 test_that("estimate_profiles() works in terms of MPlus benchmarks", {
-  x <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, model = 1, n_profiles = 3)
+  x <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, variances = "equal", covariances = "zero", n_profiles = 3)
   y <- dplyr::group_by(x, profile)
   z <- dplyr::summarize_all(y, mean)
 
@@ -22,14 +22,14 @@ test_that("estimate_profiles() works in terms of MPlus benchmarks", {
   expect_equal(dplyr::pull(z, Petal.Width)[3], 2.07, tolerance = .01)
 })
 
-test_that("different models (1-4) for estimate_profiles() works", {
-  m1 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, model = 1, n_profiles = 3)
-  m2 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, model = 2, n_profiles = 3)
-  m3 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, model = 3, n_profiles = 3)
-  m4 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, model = 6, n_profiles = 3)
+test_that("different models for estimate_profiles() works", {
+  m1 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, variances = "equal", covariances = "zero", n_profiles = 3)
+  m3 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, variances = "equal", covariances = "equal", n_profiles = 3)
+  m2 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, variances = "varying", covariances = "zero", n_profiles = 3)
+  m4 <- estimate_profiles(iris, Sepal.Length, Sepal.Width, Petal.Length, Petal.Width, variances = "varying", covariances = "varying", n_profiles = 3)
 
   expect_equal(attributes(m1)$mclust_output$loglik, -361.429, tolerance = .001)
-  expect_equal(attributes(m2)$mclust_output$loglik, -256.355, tolerance = .001)
-  expect_equal(attributes(m3)$mclust_output$loglik, -307.181, tolerance = .001)
+  expect_equal(attributes(m3)$mclust_output$loglik, -256.355, tolerance = .001)
+  expect_equal(attributes(m2)$mclust_output$loglik, -307.181, tolerance = .001)
   expect_equal(attributes(m4)$mclust_output$loglik, -180.186, tolerance = .001)
 })
